@@ -11,7 +11,6 @@ use std::{
     io::{BufReader, Read, Write},
     process::exit,
 };
-use tiny_keccak::{Hasher, KangarooTwelve};
 
 pub fn decrypt_file(
     input: &str,
@@ -37,23 +36,21 @@ pub fn decrypt_file(
         }
     }
 
-    let file = File::open(input).context("Unable to open the input file")?;
-    let mut reader = BufReader::new(file);
-    let mut data = Vec::new(); // our file bytes
-    reader
-        .read_to_end(&mut data)
-        .context("Unable to read the input file")?;
-    drop(reader);
+    let mut file = File::open(input).context("Unable to open the input file")?;
+    let mut data = Vec::new();
+    file.read_to_end(&mut data)?;
+    drop(file);
 
     if sha_sum {
         let start_time = Instant::now();
-        let mut hash = [0u8; 32];
-        let mut hasher = KangarooTwelve::new(&[]);
-        hasher.update(&data);
-        hasher.finalize(&mut hash);
-        let hash_b64 = base64::encode(hash);
+        let hash = blake3::hash(&data).to_hex();
+        
         let duration = start_time.elapsed();
-        println!("Hash of the encrypted file is: {} [took {:.2}s]", hash_b64, duration.as_secs_f32());
+        println!(
+            "Hash of the encrypted file is: {} [took {:.2}s]",
+            hash,
+            duration.as_secs_f32()
+        );
 
         let answer = get_answer(
             "Would you like to continue with the decryption?",
@@ -69,6 +66,8 @@ pub fn decrypt_file(
     let data_json: DexiosFile =
         serde_json::from_slice(&data).context("Unable to read JSON from input file")?;
 
+    drop(data);
+
     let raw_key = if !use_keyfile {
         // if we're not using a keyfile, read from stdin
         let input = rpassword::prompt_password("Password: ").context("Unable to read password")?;
